# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:control_flag) do
  include EasyType

  desc <<-DESC
  The control flag.

  Here is an example on how to use this:

      wls_authentication_provider{'my_provider':
        ...
        control_flag => 'REQUIRED',
        ...
      }

  In older versions of the `wls_config` module, This property used Captialized key words. Now
  all upcase keywords are required.

  Specifies how the authentication provider behaviour influences the total flow.
  For more information checkout the documentation of propery [DefaultAuthenticatorMBean.ControlFlag](http://docs.oracle.com/middleware/1213/wls/WLMBR/mbeans/DefaultAuthenticatorMBean.html#ControlFlag)
  in the WebLogic documentation.

  DESC

  newvalues('REQUIRED', 'REQUISITE', 'SUFFICIENT', 'OPTIONAL')

  to_translate_to_resource do |raw_resource|
    raw_resource['control_flag']
  end

  data_type("Optional[Enum['REQUIRED','REQUISITE','SUFFICIENT','OPTIONAL']]")
end
