# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:data_source_for_session_persistence, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  To support HTTP Session failover across data centers, a datasource is required to dump session state on disk.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         data_source_for_session_persistence => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:data_source_for_session_persistence']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('DataSourceForSessionPersistence/')
end
