# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:migration_basis, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Controls the mechanism used for server and service migration. <ul> <li>Database -- Requires the availability of a high-availability database, such as Oracle RAC, to store leasing information. <li>Consensus -- Stores the leasing information in-memory within a cluster member. This option requires Node Manager to be configured and running. </ul> Note: Within a WebLogic Server installation, you can only use one type of leasing. Although it is possible to implement multiple features that use leasing within your environment, each must use the same kind of leasing.

  An example on how to use this:

      wls_cluster {a_wls_cluster :
         ...
         migration_basis => 'database'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_cluster:migration_basis']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('MigrationBasis')
end
