# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:transport, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specify the underlying transport protocol to use for cluster communication. The TMB, SDMB, or IMB are only applicable to Exalogic environment.

  An example on how to use this:

      wls_coherence_cluster {a_wls_coherence_cluster :
         ...
         transport => 'udp'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_coherence_cluster:transport']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('CoherenceClusterResource/%<coherence_cluster_name>s/CoherenceClusterParams/%<coherence_cluster_name>s/Transport')
end
