# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:unicastport, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Types::Integer
  include EasyType::Validators::PortNumber

  desc <<-DESC
  The port for the cluster unicast listener. A value of 0 indicates that the unicast listener port value will be derived from the server listen port. This value or the derived value will be used only if the CoherenceMemberConfigMBean unicast listen port is 0.

  Here is an example on how to use this on a coherence cluster:

      wls_coherence_cluster{'my_coherence_cluster':
        ...
        unicastport => '9000',
        ...
      }

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('CoherenceClusterResource/%<coherence_cluster_name>s/CoherenceClusterParams/%<coherence_cluster_name>s/UnicastListenPort') { nil }
end
