# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:nm_socket_create_timeout_in_millis, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Returns the timeout value to be used by NodeManagerRuntime when creating a socket connection to the agent. Default set high as SSH agent may require a high connection establishment time.

  An example on how to use this:

      wls_coherence_server {a_wls_coherence_server :
         ...
         nm_socket_create_timeout_in_millis => '180000'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_coherence_server:nm_socket_create_timeout_in_millis']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('NMSocketCreateTimeoutInMillis')
end
