# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:start_java_vendor, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The Java Vendor value to use when starting this server.   If the server is part of a cluster and configured for automatic migration across possibly different platforms with different vendors providing the JDKs, then, both JavaVendor and JavaHome should be set in the generated configuration file instead.

  An example on how to use this:

      wls_coherence_server {a_wls_coherence_server :
         ...
         start_java_vendor => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_coherence_server:start_java_vendor']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('CoherenceServerStart/%<coherence_server_name>s/JavaVendor')
end
