# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:oracle_fan_enabled, :parent => Puppet::Parameter::WlsProperty) do
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Enables the data source to subscribe to and process Oracle FAN events.  This attribute is only applicable for RAC configurations that publish FAN notification events using the ONS protocol.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         oracle_fan_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:oracle_fan_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCOracleParams/%<datasource_name>s/FanEnabled')
end
