# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_shrink_frequency_seconds, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The number of seconds to wait before shrinking a connection pool that has incrementally increased to meet demand.  When set to <code>0</code>, shrinking is disabled.

  An example on how to use this:

      wls_datasource {a_wls_datasource :
         ...
         pool_shrink_frequency_seconds => '900'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_datasource:pool_shrink_frequency_seconds']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JDBCResource/%<datasource_name>s/JDBCConnectionPoolParams/%<datasource_name>s/ShrinkFrequencySeconds')
end
