# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:user, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
    The username to use when connection to the database.

    This specfies the username to be used when connecting to the data

        wls_datasource { 'a_datasource':
          ...
          user   => 'a_username',
          ...
        }


    The dataource user name is stored as a property in the connection pool. So if you have more properties,
    it is recomended that you just use the ` extraproperties`  value. An example:

        wls_datasource { 'a_datasource':
          ...
          extraproperties                  => ['aaaa=1','bbbb=2', 'user=a_username'],
          ...
        }

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<datasource_name>s/JDBCDriverParams/%<datasource_name>s/Properties/%<datasource_name>s/Properties/user/Value') { '' }

  on_apply do
    property_key = Kernel.format('/JDBCSystemResources/%<datasource_name>s/JDBCResource/%<datasource_name>s/JDBCDriverParams/%<datasource_name>s/Properties/%<datasource_name>s/user', resource.to_hash)
    wls_config.create_property(property_key)
    apply_paths(value)
  end
end
