# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:administration_port, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  The common secure administration port for this WebLogic Server domain. (Requires you to enable the administration port.)

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         administration_port => '9002'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:administration_port']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer[0,9999]]]")

  maps_to('AdministrationPort')
end
