# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:configuration_audit_type, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  Returns the criteria used for auditing configuration events  (configuration changes and other operations): <ul> <li><code>CONFIG_CHANGE_NONE</code> Configuration events will neither be written to the server log or directed to the Security Audit Framework.</li> <li><code>CONFIG_CHANGE_LOG</code> Configuration events will be written to the server log.</li> <li><code>CONFIG_CHANGE_AUDIT</code>Configuration events will be directed to the Security Audit Framework.</li> <li><code>CONFIG_CHANGE_LOG_AND_AUDIT</code> Configuration events will be written to the server log and directed to the Security Audit Framework.</li> </ul>

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         configuration_audit_type => 'none'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:configuration_audit_type']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('ConfigurationAuditType')
end
