# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:console_session_timeout, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include EasyType::Validators::Integer
  data_type('Optional[Variant[Enum["absent"],Integer[0,9999]]]')

  desc <<-DESC
  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         console_session_timeout => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:console_session_timeout']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('AdminConsole/%<domain_name>s/SessionTimeout')
end
