# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:java_service_enabled, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Specifies whether features to support the use of this WebLogic Server as a Java Service in a cloud environment should be enabled.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         java_service_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:java_service_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JavaServiceEnabled')
end
