# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jmx_compatibility_mbean_server_enabled, :parent => Puppet::Parameter::WlsProperty) do
  extend  Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  desc <<-DESC
  Enables JMX clients to use the deprecated <code>MBeanHome</code> interface. Prior to 9.0, WebLogic Server supported a typed API layer over its JMX layer. Your JMX application classes could import type-safe interfaces for WebLogic Server MBeans, retrieve a reference to the MBeans through the <code>weblogic.management.MBeanHome</code> interface, and invoke the MBean methods directly.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jmx_compatibility_mbean_server_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jmx_compatibility_mbean_server_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JMX/%<domain_name>s/CompatibilityMBeanServerEnabled')
end
