# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jta_max_transactions, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  The maximum number of simultaneous in-progress transactions allowed on a server in this WebLogic Server domain.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         jta_max_transactions => '10000'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:jta_max_transactions']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('JTA/%<domain_name>s/MaxTransactions')
end
