# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:security_web_app_files_case_insensitive, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource

  desc <<-DESC
  This property defines the case sensitive URL-pattern matching behavior for security constraints, servlets, filters, virtual-hosts, and so on, in the Web application container and external security policies.  Note: This is a Windows-only flag that is provided for backward compatibility when upgrading from pre-9.0 versions of WebLogic Server. On Unix platforms, setting this value to <code>true</code> causes undesired behavior and is not supported.  When the value is set to <code>os</code>, the pattern matching will be case- sensitive on all platforms except the Windows file system.  Note that on non-Windows file systems, WebLogic Server does not enforce case sensitivity and relies on the file system for optimization. As a result, if you have a Windows Samba mount from Unix or Mac OS that has been installed in case-insensitive mode, there is a chance of a security risk. If so, specify case-insensitive lookups by setting this attribute to <code>true</code>.  Note also that this property is used to preserve backward compatibility on Windows file systems only. In prior releases, WebLogic Server was case- insensitive on Windows. As of WebLogic Server 9.0, URL-pattern matching is strictly enforced.  During the upgrade of older domains, the value of this parameter is explicitly set to <code>os</code> by the upgrade plug-in to preserve backward compatibility.

  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         security_web_app_files_case_insensitive => 'false'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:security_web_app_files_case_insensitive']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('SecurityConfiguration/%<domain_name>s/WebAppFilesCaseInsensitive')
end
