# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:webappcompression_gzip_compression_content_type, :array_matching => :all, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  data_type('Optional[Array[String[1]]]')

  desc <<-DESC
  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         webappcompression_gzip_compression_content_type => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:webappcompression_gzip_compression_content_type']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  on_apply do
    apply_paths_with_array(value.join(','))
  end

  maps_to('WebAppContainer/%<domain_name>s/GzipCompression/%<domain_name>s/GzipCompressionContentType')
end
