# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:webappcontainer_max_post_time_secs, :parent => Puppet::Parameter::WlsProperty) do
  extend Puppet_X::EnterpriseModules::WebLogic::DomainPaths # Changes the actual path for domain resource
  include EasyType::Validators::Integer
  data_type('Optional[Variant[Enum["absent"],Integer]]')

  desc <<-DESC
  An example on how to use this:

      wls_domain {a_wls_domain :
         ...
         webappcontainer_max_post_time_secs => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_domain:webappcontainer_max_post_time_secs']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('WebAppContainer/%<domain_name>s/MaxPostTimeSecs')
end
