# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:statement) do
  include EasyType
  include Puppet_X::EnterpriseModules::WebLogic::Access
  include EasyType::Helpers
  include EasyType::Template

  desc 'The wlst statement or script to execute'
  data_type('Optional[String]')
  #
  # Let the insync? check for the parameter unless and the refreshonly
  #
  def insync?(_to)
    if resource[:refreshonly].to_s == 'true'
      true
    else
      resource[:unless] ? unless_value? : false
    end
  end

  private

  def unless_value?
    domain    = resource[:domain]
    statement = resource[:unless]
    cwd       = resource[:cwd]
    #
    # First fo to the specified working dirctory if specified
    #
    fail "Working directory '#{cwd}' does not exist" if cwd && !File.directory?(cwd)

    FileUtils.cd(resource[:cwd]) if resource[:cwd]
    if is_script?(statement)
      file_name = statement.split('@').last
      fail "File #{file_name} doesn't exist. " unless File.exist?(file_name)

      statement = File.read(file_name)
    end
    statement = statement.indent(2)
    environment = { 'action' => 'execute', 'type' => 'wls_exec' }
    output = wlst template('wls_config/wls_exec/execute.py.erb', binding), environment
    !output.empty?
  end

  # rubocop:disable Naming/PredicateName
  def is_script?(statement)
    # rubocop:enable Naming/PredicateName
    statement[0] == '@'
  end
end
