# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:initial_context_factory, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The name of the class that must be instantiated to access the JNDI provider. This class name depends on the JNDI provider and the vendor that are being used.  This value corresponds to the standard JNDI property, <code>java.naming.factory.initial</code>.  Note: This value defaults to <code>weblogic.jndi.WLInitialContextFactory</code>, which is the correct value for WebLogic Server.

  An example on how to use this:

      wls_foreign_server {a_wls_foreign_server :
         ...
         initial_context_factory => 'weblogic.jndi.WLInitialContextFactory'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_foreign_server:initial_context_factory']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('InitialContextFactory')
end
