# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:classpath, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The <tt>CLASSPATH</tt> of the bridge destination.  <ul> <li> Used mainly to connect to another release of WebLogic Server. </li>  <li> When connecting to a destination that is running on WebLogic Server 6.0 or earlier, the bridge destination must supply a <tt>CLASSPATH</tt> that indicates the locations of the classes for the earlier WebLogic Server implementation. </li>  <li> When connecting to a third-party JMS product, the bridge destination must supply the product's <tt>CLASSPATH</tt> in the WebLogic Server <tt>CLASSPATH</tt>. </li> </ul>

  An example on how to use this:

      wls_jms_bridge_destination {a_wls_jms_bridge_destination :
         ...
         classpath => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_bridge_destination:classpath']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('Classpath')
end
