# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:client_acknowledge_policy, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Acknowledge policy for non-transacted sessions that use the <code>CLIENT_ACKNOWLEDGE</code> mode. <code>All</code> indicates that calling acknowledge on a message acknowledges all unacknowledged messages received on the session. <code>Previous</code> specifies that calling acknowledge on a message acknowledges only unacknowledged messages up to, and including, the given message.  This parameter works around a change in the JMS specification and only applies to implementations that use the <code>CLIENT_ACKNOWLEDGE</code> acknowledge mode for a non-transacted session. Specifically, the specification allowed users to acknowledge all messages before and including the message being acknowledged. The specification was changed so that acknowledging any message acknowledges all messages ever received (even those received after the message being acknowledge).   <code>ACKNOWLEDGE_PREVIOUS</code> retains the old behavior (acknowledge all message up to and including the message being acknowledged). Whereas, <code>ACKNOWLEDGE_ALL</code> yields the new behavior, where all messages received by the given session are acknowledged regardless of which message is being used to effect the acknowledge. This attribute is dynamic and can be changed at any time. However, changing the value does not affect existing connections. It only affects new connections made with this connection factory.

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         client_acknowledge_policy => 'All'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:client_acknowledge_policy']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('ClientParams/%<connection_factory_name>s/AcknowledgePolicy')
end
