# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:lb_load_balancing_enabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether non-anonymous producers created through a connection factory are load balanced within a distributed destination on a per-call basis. <ul> <li>If enabled, the associated message producers are load balanced on every <code>send()</code> or <code>publish() </code>.</li>  <li>If disabled, the associated message producers are load balanced on the first <code>send()</code> or <code> publish()</code>.</li> </ul>

  An example on how to use this:

      wls_jms_connection_factory {a_wls_jms_connection_factory :
         ...
         lb_load_balancing_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_connection_factory:lb_load_balancing_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('LoadBalancingParams/%<connection_factory_name>s/LoadBalancingEnabled')
end
