# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_message_logging_format, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Defines which information about the message is logged. Valid values are: <ul> <li> %header% - All JMS header fields are logged. <li> %properties% - All user-defined properties are logged. <li> JMSDeliveryTime - This WebLogic JMS-specific extended header field is logged. <li> JMSRedeliveryLimit - This WebLogic JMS-specific extended header field is logged. <li> foo  - Any valid JMS header field or user-defined property is logged. </ul>   When specifying multiple values, enter them as a comma-separated list. The <tt>%header%</tt> and <tt>%properies% </tt> values are not case sensitive. For example, you could use <tt>"%header%,%properties%"</tt> for all the JMS header fields and user properties. However, the enumeration of individual JMS header fields and user-defined properties are case sensitive. To enumerate only individual JMS header fields you could use <tt>"%header, name, address, city, state, zip"</tt> .   Note: The <tt>JMSMessageID</tt> field is always logged and cannot be turned off. Therefore, if the Message Logging Format is not defined (i.e., null) or is defined as an empty string, then the output to the log file contains only the <tt>JMSMessageID</tt> of the message. Gets the "message-logging-format" element

  An example on how to use this:

      wls_jms_queue {a_wls_jms_queue :
         ...
         log_message_logging_format => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_queue:log_message_logging_format']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('MessageLoggingParams/%<queue_name>s/MessageLoggingFormat')
end
