# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:shared, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
   Indicates whether this quota is shared by multiple destinations that refer to it.  If <code>Shared</code> is enabled (the default), all destinations referring to the quota object compete for  resources the resources defined by that object. If one destination consumes a large number of messages or bytes, then this will prevent other destinations from obtaining quota.  If <code>Shared</code> is disabled, the quota object behaves as a template. Each destination referring to the quota object gets its own internal instance of the object for tracking quota.  Destinations within the same JMS module may share quotas in any way they want. However, quota sharing only takes place for destinations within the same JMS server. In other words, if destinations X and Y both share the same quota Q, and the quota Q has <code>Shared</code> enabled, then X and Y will only share quota if both are deployed to the same JMS server.

  An example on how to use this:

      wls_jms_quota {a_wls_jms_quota :
         ...
         shared => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_quota:shared']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('Shared')
end
