# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:property, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies a message property name or the name of a message header field on which to sort messages. Message header field keys ignore the key type and reference message header fields rather than message properties.   Note: For better performance, use message header fields as sorting keys, rather than message properties.   Range of Values:   The JMS Property name (including user properties) or message header fields that can be sorted on are: <ul> <li> JMSMessageID <li> JMSTimestamp <li> JMSCorrelationID <li> JMSPriority <li> JMSExpiration <li> JMSType <li> JMSRedelivered <li> JMSDeliveryTime <li> JMS_BEA_Size <li> JMS_BEA_UnitOfOrder </ul>   This attribute is not dynamically configurable. Gets the "property" element

  An example on how to use this:

      wls_jms_sort_destination_key {a_wls_jms_sort_destination_key :
         ...
         property => 'JMSMessageID'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_sort_destination_key:property']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('Property')
end
