# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:delivery_redelivery_limit, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The number of redelivery tries a message can have before it is moved to the error destination. This setting overrides any redelivery limit set by the message sender. If the redelivery limit is configured, but no error destination is configured, then persistent and non-persistent messages are simply dropped (deleted) when they reach their redelivery limit.  The default value (-1) specifies that the destination will not override the message sender's redelivery limit setting.   Note: WebLogic Server supports the JMSXDeliveryCount message property, which specifies the number of message delivery attempts, where the first attempt is 1, the next attempt is 2, and so on. WebLogic Server makes a best effort to persist the delivery count, so that the delivery count does not reset back to 1 after a server reboot.  This attribute is dynamically configurable, but only incoming messages are impacted; previously sent messages continue to use their original redelivery limit.

  An example on how to use this:

      wls_jms_topic {a_wls_jms_topic :
         ...
         delivery_redelivery_limit => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_jms_topic:delivery_redelivery_limit']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('DeliveryFailureParams/%<topic_name>s/RedeliveryLimit')
end
