# frozen_string_literal: true

newproperty(:long_running_priority, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Types::Integer

  desc <<-DESC
   An integer that specifies the long-running daemon thread's priority. If a value is specified, all long-running threads are affected.

  An example on how to use this:

      wls_managed_executor_service_template {a_wls_managed_executor_service_template :
         ...
         long_running_priority => '5'
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  validate do |value|
    fail 'value must be between 0 and 10' if (value < 1) || (value > 10)
  end

  maps_to('LongRunningPriority')
end
