# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:durability_enabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether or not the messaging bridge allows durable messages.  When enabled and the source destination is a JMS topic, a messaging bridge instance uses a durable subscription to ensure that no messages are lost in the event of a failure. <code>DurabilityEnabled</code> ignored if the source destination is a JMS queue.  <ul> <li> When enabled and the source destination uses durable subscriptions, the source JMS implementation saves messages that are sent when a messaging bridge instance is not running. When the bridge instance is restarted, these messages are forwarded to the target destination. The administrator can choose not to be durable. </li>  <li> When not enabled, messages that are sent to the source JMS implementation while the bridge instance is down cannot be forwarded to the target destination. </li> </ul>

  An example on how to use this:

      wls_messaging_bridge {a_wls_messaging_bridge :
         ...
         durability_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_messaging_bridge:durability_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('DurabilityEnabled')
end
