# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:idle_time_maximum, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The maximum amount of time, in seconds, that a messaging bridge instance remains idle.  <ul> <li> In asynchronous mode, this is the longest amount of time a messaging bridge instance stays idle before it checks the sanity of its connection to the source. </li>  <li> In synchronous mode, this is the amount of time the messaging bridge can block on a receive call if no transaction is involved. </li> </ul>

  An example on how to use this:

      wls_messaging_bridge {a_wls_messaging_bridge :
         ...
         idle_time_maximum => '60'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_messaging_bridge:idle_time_maximum']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('IdleTimeMaximum')
end
