# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:restart_in_place, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Enables periodic automatic restart of failed cluster targeted JMS artifact instance(s) running on healthy WebLogic Server instances.  Restart attempts occur before attempts to migrate an instance to a different server in the cluster. When this setting is configured on a Store it applies to all JMS artifacts that reference the store.  <ul> <li>Restarts occur when Restart In Place is set to <code>true</code>, the JMS artifact is cluster targeted, and the Migration Policy is set to <code>On-Failure</code> or <code>Always></code>.</li>  <li>This attribute is not used by WebLogic Messaging Bridges which automatically restart internal connections as needed. </li>  </ul>

  An example on how to use this:

      wls_messaging_bridge {a_wls_messaging_bridge :
         ...
         restart_in_place => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_messaging_bridge:restart_in_place']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('RestartInPlace')
end
