# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:post_script_failure_fatal, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether or not a failure during execution of the post-deactivation script is fatal to the migration.  If it is fatal, the migratable target will not be automatically migrated until an administrator manually migrates it to a server, thus reactivating it.  Note: Enabling this value will result in weakening the exactly-once guarantee. It is provided to prevent more dangerous data corruption if the post-deactivation script fails. Also if this value is enabled, then the script may be called more than once by the migration framework after the Migratable Target is deactivated or the server or machine hosting the Migratable Target crashed or is network partitioned. The script is expected not to return different exit values when invoked multiple times in such scenarios.

  An example on how to use this:

      wls_migratable_target {a_wls_migratable_target :
         ...
         post_script_failure_fatal => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_migratable_target:post_script_failure_fatal']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean

  maps_to('PostScriptFailureFatal')
end
