# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pre_script, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies the path to the pre-migration script to run before a migratable target is actually activated. The script must be in the <code>MIDDLEWARE_HOME/user_projects/domains/mydomain/bin/service_migration</code> directory.  Before the migratable target is activated, if there is a script specified, and Node Manager is available, then the script will run. Specifying a script without an available Node Manager will result in an error upon migration.  If the script fails or cannot be found, migration will not proceed on the current server, and will be tried on the next suitable server. This could be the next server in the candidate server list, or in the cluster, if there is no candidate server list.

  An example on how to use this:

      wls_migratable_target {a_wls_migratable_target :
         ...
         pre_script => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_migratable_target:pre_script']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('PreScript')
end
