# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:notes, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Optional information that you can include to describe this configuration.  WebLogic Server saves this note in the domain's configuration file (<code>config.xml</code>) as XML PCDATA. All left angle brackets (&lt;) are converted to the XML entity <code>&amp;lt;</code>. Carriage returns/line feeds are preserved.  <dl> <dt>Note:</dt>  <dd> If you create or edit a note from the Administration Console, the Administration Console does not preserve carriage returns/line feeds. </dd> </dl>

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         notes => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:notes']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('Notes')
end
