# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:oracle_ons_node_list, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  A comma-separate list of ONS daemon listen addresses and ports to which connect to for receiving ONS-based FAN events. It is required when connecting to Oracle 11g databases and optional when connecting to Oracle database releases 12c and higher.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         oracle_ons_node_list => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:oracle_ons_node_list']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCOracleParams/%<multi_datasource_name>s/OnsNodeList')
end
