# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:oracle_optimize_utf8_conversion, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Enables the Oracle JDBC optimize UTF-8 conversion option.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         oracle_optimize_utf8_conversion => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:oracle_optimize_utf8_conversion']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCOracleParams/%<multi_datasource_name>s/OracleOptimizeUtf8Conversion')
end
