# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_connection_labeling_callback, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The class name of the connection labeling callback. This is automatically passed to registerConnectionLabelingCallback when the datasource is created. The class must implement <code>oracle.ucp.ConnectionLabelingCallback</code>.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         pool_connection_labeling_callback => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:pool_connection_labeling_callback']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  data_type('Optional[String]')

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCConnectionPoolParams/%<multi_datasource_name>s/ConnectionLabelingCallback')
end
