# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:pool_test_connections_on_reserve, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Enables WebLogic Server to test a connection before giving it to a client. (Requires that you specify a Test Table Name.)  The test adds a small delay in serving the client's request for a connection from the pool, but ensures that the client receives a viable connection.

  An example on how to use this:

      wls_multi_datasource {a_wls_multi_datasource :
         ...
         pool_test_connections_on_reserve => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_multi_datasource:pool_test_connections_on_reserve']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JDBCResource/%<multi_datasource_name>s/JDBCConnectionPoolParams/%<multi_datasource_name>s/TestConnectionsOnReserve')
end
