# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:jndi_prefix, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies the string that will prefix the local JNDI name of a remote destination.  Any change to this prefix affects only incoming messages; stored messages are not affected.

  An example on how to use this:

      wls_saf_imported_destination {a_wls_saf_imported_destination :
         ...
         jndi_prefix => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_saf_imported_destination:jndi_prefix']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('JNDIPrefix')
end
