# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_safagent) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc <<-DESC
    This resource allows you to manage a SAF agent in an WebLogic domain.

    Here is an example on how you should use this:

        wls_safagent { 'jmsSAFAgent1':
          ensure              => 'present',
          persistentstore     => 'jmsFileSAFAgent1',
          persistentstoretype => 'FileStore',
          servicetype         => 'Sending-only',
          target              => ['wlsServer1'],
          targettype          => ['Server'],
        }

    In this example you are managing a SAF agent in the default domain. When you want to
    manage a SAF agent in a specific domain, you can use:

        wls_safagent { 'my_domain/jmsSAFAgent2':
          ensure      => 'present',
          servicetype => 'Both',
          target      => ['wlsServer2'],
          targettype  => ['Server'],
        }

    DESC

    bean_type('SAFAgent')

    ensurable
    parameter :safagent_name
    parameter :domain
    parameter :name
    parameter :timeout

    property :servicetype
    property :persistentstore
    property :persistentstoretype
    property :target
    property :targettype
    extraproperties do
      property :acknowledge_interval
      property :default_retry_delay_maximum
      property :deployment_order
      property :log_buffer_size_kb
      property :log_file_count
      property :log_file_min_size
      property :log_file_name
      property :log_file_rotation_dir
      property :log_file_time_span
      property :log_notes
      property :log_number_of_files_limited
      property :log_rotate_log_on_startup
      property :log_rotation_time
      property :log_rotation_type
      property :store_message_compression_enabled
      property :conversation_idle_time_maximum
      property :default_retry_delay_base
      property :default_retry_delay_multiplier
      property :default_time_to_live
      property :incoming_paused_at_startup
      property :logging_enabled
      property :maximum_message_size
      property :message_buffer_size
      property :message_compression_options
      property :messages_maximum
      property :messages_threshold_high
      property :messages_threshold_low
      property :notes
      property :paging_message_compression_enabled
      property :receiving_paused_at_startup
      property :bytes_maximum
      property :bytes_threshold_high
      property :bytes_threshold_low
      property :forwarding_paused_at_startup
      property :paging_directory
      property :service_type
      property :window_interval
      property :window_size
      #
      # Weblogic 12.2.1 new properties
      #
      property :log_date_format_pattern
      property :log_tags
      property :store
      property :tags
    end

    add_title_attributes(:safagent_name)
  end
end
