# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:default_retry_delay_base, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The amount of time, in milliseconds, between the original delivery attempt and the first retry.  <ul> <li> If <code>RetryDelayMultiplier</code> is set to <code>1</code>, this defines the interval between any two successive retry attempts. </li>  <li> Applies only to agents with sending capability. </li>  <li> Updating <code>DefaultRetryDelayBase</code> causes connections starting after the update to use the new value. </li> </ul>  Range of Values: &lt;= RetryDelayMaximum if RetryDelayMultiplier is not 1.0.

  An example on how to use this:

      wls_safagent {a_wls_safagent :
         ...
         default_retry_delay_base => '20000'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_safagent:default_retry_delay_base']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC
  include EasyType::Types::Integer
  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to('DefaultRetryDelayBase')
end
