# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:forwarding_paused_at_startup, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Specifies whether the agent is paused for forwarding messages at the startup time.  When enabled, the sending agent forwards messages. Otherwise, the sending agent does not forward any messages.

  An example on how to use this:

      wls_safagent {a_wls_safagent :
         ...
         forwarding_paused_at_startup => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_safagent:forwarding_paused_at_startup']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('ForwardingPausedAtStartup')
end
