# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:arguments, :array_matching => :all, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::ArrayProperty

  desc <<-DESC
    The server start arguments of the server.

    Can be specified as an array or a space separated string'
  DESC
  # or both...
  # The following should also work
  # arguments => ['arg1 arg2','arg3','arg4 arg5']
  # and be idempotent with 'arg4 arg3 arg1 arg2 arg5' and [arg1,arg4,arg2,'arg3 arg5'] etc

  maps_to('ServerStart/%<server_name>s/Arguments')
  array_separator(/\s/) # This property returns an string that must be transformed
  # into an array by splitting on white space

  def unsafe_validate(value)
    # The ArrayProperty checks for comma's in the values
    # unfortunately some of the real values for this property **CAN** contain valid comma's
    # To allow those values, we override the validator and allow everything to be valid
  end

  munge do |value|
    raise Puppet::Error "Invalid server start argument: #{value.inspect}" unless value.is_a?(String)

    value.split(/\s/)
  end

  def should
    return nil unless defined?(@should)

    # Return simple array out of possibly nested one.  eg [['bar'],['foo','foobar']] into ['bar','foo','foobar']
    @should.join(' ').split
  end

  on_apply do
    apply_paths(value.join(' '))
  end
end
