# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:buzz_enabled, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Enables Buzz for sending/receiving messages with peers. Enabling this attribute increases efficiency during I/O in environments with high network throughput and should be used only when configuring a WebLogic domain for Oracle Exalogic.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         buzz_enabled => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:buzz_enabled']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('BuzzEnabled')
end
