# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_memory_buffer_size, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The size of the memory buffer that holds the last n log records. This is used to support viewing the most recent log record entries (tail viewing) from the WebLogic Administration Console.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         log_memory_buffer_size => '10'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:log_memory_buffer_size']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('Log/%<server_name>s/MemoryBufferSize')
end
