# frozen_string_literal: true

newproperty(:migration_strict_ownership_check, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Whether continue to boot if cannot find the current owner of TRS to do failback. This attribute is only meaningful for servers in cluster.   If true: server will fail to boot under this situation. If false: server will continue to boot without trying to do failback.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         migration_strict_ownership_check => '1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:migration_strict_ownership_check']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('JTAMigratableTarget/%<server_name>s/StrictOwnershipCheck') {}
end
