# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:muxer_class, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Non-blocking IO is enabled by default on the server side. The default value is <code>weblogic.socket.NIOSocketMuxer</code>.  The Certicom SSL implementation is not supported with NIOSocketMuxer. If you need to secure internet communication, Oracle recommends enabling JSSE (Java Secure Socket Extension).

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         muxer_class => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:muxer_class']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('MuxerClass')
end
