# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:overload_panic_action, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Exit the server process when the kernel encounters a panic condition like an unhandled OOME. An unhandled OOME could lead to inconsistent state and a server restart is advisable if backed by node manager or a HA agent.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         overload_panic_action => 'system-exit'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:overload_panic_action']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('OverloadProtection/%<server_name>s/PanicAction')
end
