# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ssl_client_cert_private_key_pass_phrase, :parent => Puppet::Parameter::WlsEncryptedProperty) do
  desc <<-DESC
  The passphrase used to retrieve the private key for the client SSL certificate specified in <code>{@link #getClientCertAlias}</code> from the server configured keystore. This passphrase is assigned to the private key when the private key is generated. <p/> Note that this attribute is usually used when outbound SSL connections specify a client SSL certificate identity. <p/> Note that when you get the value of this attribute, WebLogic Server does the following: <ol> <li>Retrieves the value of the <code>ClientCertPrivateKeyPassPhraseEncrypted</code> attribute. <li>Decrypts the value and returns the unencrypted passphrase. </ol>

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         ssl_client_cert_private_key_pass_phrase => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:ssl_client_cert_private_key_pass_phrase']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('SSL/%<server_name>s/ClientCertPrivateKeyPassPhrase')
end
