# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:webserver_default_web_app_context_root, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Returns the original context-root for the default Web application for this Web server. Alternatively, you can use the context-root attributes in application.xml or weblogic.xml to set a default Web application. The context-root for a default Web application is /. If "" (empty string) is specified, the Web server defaults to /.

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         webserver_default_web_app_context_root => 'a_value'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:webserver_default_web_app_context_root']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('WebServer/%<server_name>s/DefaultWebAppContextRoot')
end
