# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:webserver_max_post_time_secs, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-DESC
  Max Post Time (in seconds) for reading HTTP POST data in a servlet request. MaxPostTime &lt; 0 means unlimited  Gets the maxPostTimeSecs attribute of the WebServerMBean object

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         webserver_max_post_time_secs => '-1'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:webserver_max_post_time_secs']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('WebServer/%<server_name>s/MaxPostTimeSecs')
end
