# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:webserver_max_request_parameter_count, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Validators::Integer

  desc <<-DESC
  Max Request Parameter Count this server allows for reading maximum HTTP POST Parameters count in a servlet request.  Gets the maxRequestParameterCount attribute of the WebServerMBean object

  An example on how to use this:

      wls_server {a_wls_server :
         ...
         webserver_max_request_parameter_count => '10000'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server:webserver_max_request_parameter_count']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('WebServer/%<server_name>s/MaxRequestParameterCount')
end
