# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:log_filecount, :parent => Puppet::Parameter::WlsProperty) do
  include EasyType::Types::Integer

  desc <<-DESC
  The maximum number of log files that the server creates when it rotates the log.
  This number does not include the file that the server uses to store current messages.
  (Requires that you enable Number of Files Limited.)

  An example on how to use this:

      ...{...:
         ...
         log_filecount => 7
         ...
      }

  Help text generated from MBEan text.
  DESC

  data_type("Optional[Variant[Enum['absent'],Integer]]")

  maps_to([
            'Log/%<server_name>s/FileCount',
            'WebServer/%<server_name>s/WebServerLog/%<server_name>s/FileCount',
            'DataSource/%<server_name>s/DataSourceLogFile/%<server_name>s/FileCount'
          ])
end
