# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:state) do
  include EasyType

  newvalues(
    'running',
    'starting',
    'standby',
    'admin',
    'resuming',
    'shutting-down',
    'suspening',
    'force_suspend',
    'failed_not_restartable',
    'shutdown'
  )

  data_type("Optional[Enum['running',
  'starting',
  'standby',
  'admin',
  'resuming',
  'shutting-down',
  'suspening',
  'force_suspend',
  'failed_not_restartable',
  'shutdown']]")
  desc <<-DESC
  The state of the managed server.

  The puppet type recognizes all possible states, but it can only manage a
  full start (e.g. move all the way to state `running`) and a full stop.
  (e.g moving all the way to state `shutdown`). When it is currently `shutdown`,
  setting it to state `admin`  for example, will result in a full start.


  DESC

  def self.translate_to_resource(raw_resource, resource)
    my_resource = raw_resource.merge(resource) # Merge raw with what we got
    wls_config = Puppet_X::EnterpriseModules::WebLogic::Tree.new(my_resource[:domain])
    value = wls_config.get("/ServerLifeCycleRuntimes/#{my_resource[:server_name]}/State", 'domainRuntime') {}
    value&.downcase! # Guard to when a nill is returned
    value
  end

  # rubocop:disable Naming/MethodParameterName
  def insync?(is)
    # rubocop:enable Naming/MethodParameterName
    if (should.to_s == 'running') && resource.running?(is)
      Puppet.debug "#{resource.name} already in a starting state #{is}, skipping action."
      return true
    elsif (should.to_s == 'shutdown') && resource.shutdown?(is)
      Puppet.debug "#{resource.name} already in a stopped state #{is}, skipping action."
      return true
    end
    super
  end

  after_create do
    resource.manage_state
  end

  after_modify do
    resource.manage_state
  end
end
