# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:add_work_manager_threads_by_cpu_count, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Enables increased efficiency of the self-tuning thread pool by aligning it with the Exalogic processor architecture threading capabilities. Use only when configuring a WebLogic domain for Oracle Exalogic. <ul> <li>Enabling this attribute increases efficiency during I/O in environments with high network throughput.</li> <li>Disabling this attribute allows the thread pool to self-tune to match the demand of the workload at the expense of longer ramp up time.</li> </ul>

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         add_work_manager_threads_by_cpu_count => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:add_work_manager_threads_by_cpu_count']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('AddWorkManagerThreadsByCpuCount')
end
