# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:listeners_bind_early, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Determines whether the server should bind server sockets early. Early binding detects port conflicts quickly and also gives user feedback on the default listen port as to the server state.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         listeners_bind_early => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:listeners_bind_early']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('ListenersBindEarly')
end
