# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:ssl_allow_unencrypted_null_cipher, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Test if the AllowUnEncryptedNullCipher is enabled see <code>setAllowUnencryptedNullCipher(boolean enable)</code> for the NullCipher feature.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         ssl_allow_unencrypted_null_cipher => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:ssl_allow_unencrypted_null_cipher']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('SSL/%<template_name>s/AllowUnencryptedNullCipher')
end
