# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:use_enhanced_priority_queue_for_request_manager, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Reduces lock contention by using the enhanced ConcurrentCalendarQueue as the priority based queue for pending requests that are waiting for a thread  This attribute should be enabled only in an Oracle Exalogic environment.

  An example on how to use this:

      wls_server_template {a_wls_server_template :
         ...
         use_enhanced_priority_queue_for_request_manager => 1,
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_template:use_enhanced_priority_queue_for_request_manager']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  include Puppet_X::EnterpriseModules::WebLogic::Types::NumberedBoolean
  data_type("Optional[Variant[Enum['absent'],Integer[0,1]]]")

  maps_to('UseEnhancedPriorityQueueForRequestManager')
end
