# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:reconnect_retry_period_millis, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  Returns the length of time in milliseconds during which the persistent store will attempt to re-establish a connection to the database.  Successive reconnection attempts will be attempted after a fixed delay that is specified by the reconnection retry interval.  The reconnection period applies to JDBC connections regardless of the database that is used for the JDBC store.  The default value is 1000

  An example on how to use this:

      wls_server_tlog {a_wls_server_tlog :
         ...
         reconnect_retry_period_millis => '1000'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_server_tlog:reconnect_retry_period_millis']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('ReconnectRetryPeriodMillis')
end
