# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:https_keep_alive_secs, :parent => Puppet::Parameter::WlsProperty) do
  desc <<-DESC
  The amount of time this server waits before closing an inactive HTTPS connection.  Number of seconds to maintain HTTPS keep-alive before timing out the request.

  An example on how to use this:

      wls_virtual_host {a_wls_virtual_host :
         ...
         https_keep_alive_secs => '60'
         ...
      }

  This is an extended property. Before you can use it add it to the `wls_settings` property `extra_properties`.

      wls_setting{'domain':
         ...
        extra_properties => ['wls_virtual_host:https_keep_alive_secs']
         ...
      }

  This help text generated from MBean text of the WebLogic server.

  DESC

  maps_to('HttpsKeepAliveSecs')
end
