# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
if RUBY_VERSION < '1.9.2'

  class KeyError < IndexError; end

  # String.class_eval do
  #
  # Ruby 1.8.7 doesn't support the use of a Hash as parameter. This implementation
  # Since we use a very basic setubset of the formatter, we implement just what we need
  #
  class String
    old_format = instance_method(:%)

    define_method(:%) do |hash|
      variables_regex = /%<(.*?)>/
      variables = scan(variables_regex).flatten
      if hash.is_a?(Hash) || variables.any?
        raise KeyError if variables.any? { |k| !hash.key?(k.to_sym) }

        gsub(variables_regex) { hash[Regexp.last_match(1).to_sym] }
      else
        old_format.bind_call(self, hash)
      end
    end
  end
end
