# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
module Puppet_X
  module EnterpriseModules
    module WebLogic
      module Settings
        def self.included(parent)
          parent.extend(Settings)
        end

        def setting_for(key)
          settings[key]
        end

        def configuration
          read_from_yaml
        end

        def settings
          configuration[environment]
        end

        def read_from_yaml
          if File.exist?(config_file)
            # rubocop:disable Security/Open
            open(config_file) { |f| YAML.safe_load(f, :permitted_classes => [Symbol]) }
            # rubocop:enable Security/Open
          else
            { 'default' => {} }
          end
        end
      end
    end
  end
end
